@@ -33,22 +33,20 @@ extern ARMCI_Group ARMCI_Node_group;
 
 static MPI_Comm wc()
 {
+    int check;
     MPI_Comm comm;
-    /*
-    assert(COMEX_SUCCESS == comex_group_comm(COMEX_GROUP_WORLD, &comm));
-    */
-    comex_group_comm(COMEX_GROUP_WORLD, &comm);
+    check = comex_group_comm(COMEX_GROUP_WORLD, &comm);
+    assert(COMEX_SUCCESS == check);
     return comm;
 }
 
 /* undocumented, but used in GA to expose MPI_Comm */
 MPI_Comm armci_group_comm(ARMCI_Group *group)
 {
+    int check;
     MPI_Comm comm;
-    /*
-    assert(COMEX_SUCCESS == comex_group_comm(*group, &comm));
-    */
-    comex_group_comm(*group, &comm);
+    check = comex_group_comm(*group, &comm);
+    assert(COMEX_SUCCESS == check);
     return comm;
 }
 
@@ -73,7 +71,7 @@ static MPI_Datatype armci_type_to_mpi_type(int type)
         mpi_dt = MPI_DOUBLE;
     }
     else {
-        assert(0);
+        comex_error("armci_type_to_mpi_type: unrecognized type", type);
     }
 
     return mpi_dt;
@@ -119,8 +117,7 @@ static MPI_Op armci_op_to_mpi_op(char *op)
         result = MPI_BOR;
     }
     else {
-        printf("Unsupported gop operation:%s\n",op);
-        assert(0);
+        comex_error("Unsupported gop operation",1);
     }
 
     return result;
@@ -146,7 +143,7 @@ static void do_abs(void *x, int n, int type)
     DO_ABS(ARMCI_FLOAT,     float,      FLT)
     DO_ABS(ARMCI_DOUBLE,    double,     FLT)
     {
-        assert(0);
+        comex_error("unsupported ABS operation", 1);
     }
 #undef ARMCI_ABS_INT
 #undef ARMCI_ABS_FLT
@@ -156,11 +153,10 @@ static void do_abs(void *x, int n, int type)
 
 static MPI_Comm get_comm(ARMCI_Group *group)
 {
+    int check;
     MPI_Comm comm;
-    /*
-    assert(COMEX_SUCCESS == comex_group_comm(*group, &comm));
-    */
-    comex_group_comm(*group, &comm);
+    check = comex_group_comm(*group, &comm);
+    assert(COMEX_SUCCESS == check);
     return comm;
 }
 
@@ -298,7 +294,7 @@ void armci_msg_sel_scope(int scope, void *x, int n, char* op, int type, int cont
         mpi_op = MPI_MAXLOC;
     }
     else {
-        assert(0);
+        comex_error("unsupported armci_msg_sel_scope operation", 1);
     }
 
 #define SELECT(ARMCI_TYPE, C_TYPE, MPI_TYPE)                    \
@@ -322,7 +318,7 @@ void armci_msg_sel_scope(int scope, void *x, int n, char* op, int type, int cont
     SELECT(ARMCI_FLOAT,     float,      MPI_FLOAT_INT)
     SELECT(ARMCI_DOUBLE,    double,     MPI_DOUBLE_INT)
     {
-        assert(0);
+        comex_error("unsupported SELECT operation", 1);
     }
 #undef SELECT
 }
@@ -340,7 +336,7 @@ void armci_msg_bcast_scope(int scope, void* buffer, int len, int root)
         MPI_Bcast(buffer, len, MPI_BYTE, root, comm);
     }
     else {
-        assert(0);
+        comex_error("unsupported armci_msg_bcast_scope scope", 1);
     }
 }
 
@@ -619,37 +615,37 @@ double armci_timer()
 
 void armci_msg_clus_brdcst(void *buf, int len)
 {
-    assert(0);
+    comex_error("armci_msg_clus_brdcst not implemented", 1);
 }
 
 
 void armci_msg_clus_igop(int *x, int n, char* op)
 {
-    assert(0);
+    comex_error("armci_msg_clus_igop not implemented", 1);
 }
 
 
 void armci_msg_clus_fgop(float *x, int n, char* op)
 {
-    assert(0);
+    comex_error("armci_msg_clus_fgop not implemented", 1);
 }
 
 
 void armci_msg_clus_lgop(long *x, int n, char* op)
 {
-    assert(0);
+    comex_error("armci_msg_clus_lgop not implemented", 1);
 }
 
 
 void armci_msg_clus_llgop(long long *x, int n, char* op)
 {
-    assert(0);
+    comex_error("armci_msg_clus_llgop not implemented", 1);
 }
 
 
 void armci_msg_clus_dgop(double *x, int n, char* op)
 {
-    assert(0);
+    comex_error("armci_msg_clus_dgop not implemented", 1);
 }
 
 
@@ -695,7 +691,7 @@ void armci_msg_group_dgop(double *x, int n,char* op, ARMCI_Group *group)
 
 void armci_exchange_address_grp(void *ptr_arr[], int n, ARMCI_Group *group)
 {
-    assert(0);
+    comex_error("armci_exchange_address_grp not implemented", 1);
 #if 0
     MPI_Datatype mpi_datatype;
 
@@ -709,7 +705,7 @@ void armci_exchange_address_grp(void *ptr_arr[], int n, ARMCI_Group *group)
         mpi_datatype = MPI_LONG_LONG;
     }
     else {
-        assert(0);
+        comex_error("armci_exchange_address_grp bad size", 1);
     }
 
     MPI_Allgather(MPI_IN_PLACE, 0, MPI_DATATYPE_NULL,
@@ -760,5 +756,5 @@ void armci_msg_group_bcast_scope(int scope, void *buf, int len, int root, ARMCI_
 
 void armci_grp_clus_brdcst(void *buf, int len, int grp_master, int grp_clus_nproc,ARMCI_Group *mastergroup)
 {
-    assert(0);
+    comex_error("armci_grp_clus_brdcst not implemented", 1);
 }
