@@ -1591,10 +1591,7 @@ test_fun (int type, int dim, int OP)
   return ok;
 }
 
-int
-main (argc, argv)
-  int argc;
-  char **argv;
+int main(int argc, char **argv)
 {
   int heap = 20000, stack = 20000;
   int me, nproc;
@@ -1674,8 +1671,6 @@ void nga_vfill_patch(Integer *g_a, Integer *lo, Integer *hi)
   _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
   if(local_sync_begin)GA_Sync(); 
 
-  GA_PUSH_NAME("nga_vfill_patch");
-
   pnga_inquire(*g_a,  &type, &ndim, dims);
 
   /* get limits of VISIBLE patch */ 
@@ -1793,7 +1788,6 @@ void nga_vfill_patch(Integer *g_a, Integer *lo, Integer *hi)
     /* release access to the data */
     pnga_release_update(*g_a, loA, hiA);
   }
-  GA_POP_NAME;
   if(local_sync_end)GA_Sync();
 }
 /*\ Utility function to actually set positive/negative values
@@ -1924,8 +1918,6 @@ void nga_pnfill_patch(Integer *g_a, Integer *lo, Integer *hi)
   _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
   if(local_sync_begin)GA_Sync(); 
 
-  GA_PUSH_NAME("nga_pnfill_patch");
-
   pnga_inquire(*g_a,  &type, &ndim, dims);
 
   num_blocks = pnga_total_blocks(*g_a);
@@ -2106,7 +2098,6 @@ void nga_pnfill_patch(Integer *g_a, Integer *lo, Integer *hi)
       }
     }
   }
-  GA_POP_NAME;
   if(local_sync_end)GA_Sync();
 }
 
